@@ -15,8 +15,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-
 
 class BaseDataModel(object):
     def to_dict(self, calling_classes=None, recurse=False,
@@ -52,8 +50,6 @@ class BaseDataModel(object):
                             calling_classes=calling_classes + [type(self)])
                     else:
                         ret[attr] = None
-                elif six.PY2 and isinstance(value, six.text_type):
-                    ret[attr.encode('utf8')] = value.encode('utf8')
                 elif isinstance(value, UnsetType):
                     if render_unsets:
                         ret[attr] = None
@@ -103,7 +99,8 @@ class LoadBalancer(BaseDataModel):
                  listeners=Unset, loadbalancer_id=Unset, name=Unset,
                  pools=Unset, project_id=Unset, vip_address=Unset,
                  vip_network_id=Unset, vip_port_id=Unset, vip_subnet_id=Unset,
-                 vip_qos_policy_id=Unset, additional_vips=Unset):
+                 vip_qos_policy_id=Unset, additional_vips=Unset,
+                 availability_zone=Unset):
 
         self.admin_state_up = admin_state_up
         self.description = description
@@ -119,6 +116,7 @@ class LoadBalancer(BaseDataModel):
         self.vip_subnet_id = vip_subnet_id
         self.vip_qos_policy_id = vip_qos_policy_id
         self.additional_vips = additional_vips
+        self.availability_zone = availability_zone
 
 
 class Listener(BaseDataModel):
@@ -135,7 +133,7 @@ class Listener(BaseDataModel):
                  client_ca_tls_container_data=Unset,
                  client_authentication=Unset, client_crl_container_ref=Unset,
                  client_crl_container_data=Unset, project_id=Unset,
-                 allowed_cidrs=Unset):
+                 allowed_cidrs=Unset, tls_versions=Unset, tls_ciphers=Unset):
 
         self.admin_state_up = admin_state_up
         self.connection_limit = connection_limit
@@ -164,6 +162,8 @@ class Listener(BaseDataModel):
         self.client_crl_container_data = client_crl_container_data
         self.project_id = project_id
         self.allowed_cidrs = allowed_cidrs
+        self.tls_versions = tls_versions
+        self.tls_ciphers = tls_ciphers
 
 
 class Pool(BaseDataModel):
@@ -175,7 +175,7 @@ class Pool(BaseDataModel):
                  tls_container_data=Unset, ca_tls_container_ref=Unset,
                  ca_tls_container_data=Unset, crl_container_ref=Unset,
                  crl_container_data=Unset, tls_enabled=Unset,
-                 project_id=Unset):
+                 project_id=Unset, tls_versions=Unset, tls_ciphers=Unset):
 
         self.admin_state_up = admin_state_up
         self.description = description
@@ -196,6 +196,8 @@ class Pool(BaseDataModel):
         self.crl_container_data = crl_container_data
         self.tls_enabled = tls_enabled
         self.project_id = project_id
+        self.tls_versions = tls_versions
+        self.tls_ciphers = tls_ciphers
 
 
 class Member(BaseDataModel):
