@@ -173,15 +173,24 @@ SUPPORTED_SSL_HEADERS = ['X-SSL-Client-Verify', 'X-SSL-Client-Has-Cert',
                          'X-SSL-Issuer', 'X-SSL-Client-SHA1',
                          'X-SSL-Client-Not-Before', 'X-SSL-Client-Not-After']
 
+# Client certification authorization options
+CLIENT_AUTH_NONE = 'NONE'
+CLIENT_AUTH_OPTIONAL = 'OPTIONAL'
+CLIENT_AUTH_MANDATORY = 'MANDATORY'
+SUPPORTED_CLIENT_AUTH_MODES = [CLIENT_AUTH_NONE, CLIENT_AUTH_OPTIONAL,
+                               CLIENT_AUTH_MANDATORY]
+
 # Constants from the provider driver API
 ACTION = 'action'
 ADDITIONAL_VIPS = 'additional_vips'
 ADDRESS = 'address'
 ADMIN_STATE_UP = 'admin_state_up'
 ALLOWED_CIDRS = 'allowed_cidrs'
+AVAILABILITY_ZONE = 'availability_zone'
 BACKUP = 'backup'
 CA_TLS_CONTAINER_DATA = 'ca_tls_container_data'
 CA_TLS_CONTAINER_REF = 'ca_tls_container_ref'
+CASCADE = 'cascade'
 CERTIFICATE = 'certificate'
 CLIENT_AUTHENTICATION = 'client_authentication'
 CLIENT_CA_TLS_CONTAINER_DATA = 'client_ca_tls_container_data'
@@ -221,6 +230,7 @@ MEMBER_ID = 'member_id'
 MONITOR_ADDRESS = 'monitor_address'
 MONITOR_PORT = 'monitor_port'
 NAME = 'name'
+NETWORK_ID = 'network_id'
 PASSPHRASE = 'passphrase'
 PERSISTENCE_GRANULARITY = 'persistence_granularity'
 PERSISTENCE_TIMEOUT = 'persistence_timeout'
@@ -246,9 +256,16 @@ TIMEOUT_CLIENT_DATA = 'timeout_client_data'
 TIMEOUT_MEMBER_CONNECT = 'timeout_member_connect'
 TIMEOUT_MEMBER_DATA = 'timeout_member_data'
 TIMEOUT_TCP_INSPECT = 'timeout_tcp_inspect'
+TLS_CIPHERS = 'tls_ciphers'
 TLS_CONTAINER_DATA = 'tls_container_data'
 TLS_CONTAINER_REF = 'tls_container_ref'
 TLS_ENABLED = 'tls_enabled'
+TLS_VERSIONS = 'tls_versions'
+SSL_VERSION_3 = 'SSLv3'
+TLS_VERSION_1 = 'TLSv1'
+TLS_VERSION_1_1 = 'TLSv1.1'
+TLS_VERSION_1_2 = 'TLSv1.2'
+TLS_VERSION_1_3 = 'TLSv1.3'
 TYPE = 'type'
 URL_PATH = 'url_path'
 VALUE = 'value'
