@@ -17,6 +17,7 @@ from copy import deepcopy
 from oslo_utils import uuidutils
 
 from octavia_lib.api.drivers import data_models
+from octavia_lib.common import constants
 from octavia_lib.tests.unit import base
 
 
@@ -44,6 +45,7 @@ class TestProviderDataModels(base.TestCase):
         self.healthmonitor_id = uuidutils.generate_uuid()
         self.l7policy_id = uuidutils.generate_uuid()
         self.l7rule_id = uuidutils.generate_uuid()
+        self.availability_zone = uuidutils.generate_uuid()
 
         self.ref_l7rule = data_models.L7Rule(
             admin_state_up=True,
@@ -99,7 +101,13 @@ class TestProviderDataModels(base.TestCase):
             client_ca_tls_container_ref=None,
             client_crl_container_data=None,
             client_crl_container_ref=None,
-            allowed_cidrs=None)
+            allowed_cidrs=None,
+            tls_versions=[constants.SSL_VERSION_3,
+                          constants.TLS_VERSION_1,
+                          constants.TLS_VERSION_1_1,
+                          constants.TLS_VERSION_1_2,
+                          constants.TLS_VERSION_1_3],
+            tls_ciphers=None)
 
         self.ref_lb = data_models.LoadBalancer(
             admin_state_up=False,
@@ -113,7 +121,8 @@ class TestProviderDataModels(base.TestCase):
             vip_network_id=self.vip_network_id,
             vip_port_id=self.vip_port_id,
             vip_subnet_id=self.vip_subnet_id,
-            vip_qos_policy_id=self.vip_qos_policy_id)
+            vip_qos_policy_id=self.vip_qos_policy_id,
+            availability_zone=self.availability_zone)
 
         self.ref_vip = data_models.VIP(
             vip_address=self.vip_address,
@@ -165,7 +174,13 @@ class TestProviderDataModels(base.TestCase):
             project_id=self.project_id,
             listener_id=self.listener_id,
             protocol='avian',
-            session_persistence=self.session_persistence)
+            session_persistence=self.session_persistence,
+            tls_versions=[constants.SSL_VERSION_3,
+                          constants.TLS_VERSION_1,
+                          constants.TLS_VERSION_1_1,
+                          constants.TLS_VERSION_1_2,
+                          constants.TLS_VERSION_1_3],
+            tls_ciphers=None)
 
         self.ref_l7rule_dict = {'admin_state_up': True,
                                 'compare_type': 'STARTS_WITH',
@@ -201,7 +216,8 @@ class TestProviderDataModels(base.TestCase):
                             'description': 'One great load balancer',
                             'vip_subnet_id': self.vip_subnet_id,
                             'name': 'favorite_lb',
-                            'vip_qos_policy_id': self.vip_qos_policy_id}
+                            'vip_qos_policy_id': self.vip_qos_policy_id,
+                            'availability_zone': self.availability_zone}
 
         self.ref_listener_dict = {
             'admin_state_up': True,
@@ -231,7 +247,13 @@ class TestProviderDataModels(base.TestCase):
             'client_ca_tls_container_ref': None,
             'client_crl_container_data': None,
             'client_crl_container_ref': None,
-            'allowed_cidrs': None, }
+            'allowed_cidrs': None,
+            'tls_versions': [constants.SSL_VERSION_3,
+                             constants.TLS_VERSION_1,
+                             constants.TLS_VERSION_1_1,
+                             constants.TLS_VERSION_1_2,
+                             constants.TLS_VERSION_1_3],
+            'tls_ciphers': None}
 
         self.ref_lb_dict_with_listener = {
             'admin_state_up': False,
@@ -245,7 +267,8 @@ class TestProviderDataModels(base.TestCase):
             'vip_network_id': self.vip_network_id,
             'vip_port_id': self.vip_port_id,
             'vip_subnet_id': self.vip_subnet_id,
-            'vip_qos_policy_id': self.vip_qos_policy_id}
+            'vip_qos_policy_id': self.vip_qos_policy_id,
+            'availability_zone': self.availability_zone}
 
         self.ref_vip_dict = {
             'vip_address': self.vip_address,
@@ -297,29 +320,35 @@ class TestProviderDataModels(base.TestCase):
             'project_id': self.project_id,
             'listener_id': self.listener_id,
             'protocol': 'avian',
-            'session_persistence': self.session_persistence}
+            'session_persistence': self.session_persistence,
+            'tls_versions': [constants.SSL_VERSION_3,
+                             constants.TLS_VERSION_1,
+                             constants.TLS_VERSION_1_1,
+                             constants.TLS_VERSION_1_2,
+                             constants.TLS_VERSION_1_3],
+            'tls_ciphers': None}
 
     def test_equality(self):
         second_ref_lb = deepcopy(self.ref_lb)
 
-        self.assertTrue(self.ref_lb == second_ref_lb)
+        self.assertEqual(self.ref_lb, second_ref_lb)
 
         second_ref_lb.admin_state_up = True
 
-        self.assertFalse(self.ref_lb == second_ref_lb)
+        self.assertNotEqual(self.ref_lb, second_ref_lb)
 
-        self.assertFalse(self.ref_lb == self.loadbalancer_id)
+        self.assertNotEqual(self.ref_lb, self.loadbalancer_id)
 
     def test_inequality(self):
         second_ref_lb = deepcopy(self.ref_lb)
 
-        self.assertFalse(self.ref_lb != second_ref_lb)
+        self.assertEqual(self.ref_lb, second_ref_lb)
 
         second_ref_lb.admin_state_up = True
 
-        self.assertTrue(self.ref_lb != second_ref_lb)
+        self.assertNotEqual(self.ref_lb, second_ref_lb)
 
-        self.assertTrue(self.ref_lb != self.loadbalancer_id)
+        self.assertNotEqual(self.ref_lb, self.loadbalancer_id)
 
     def test_to_dict(self):
         ref_lb_converted_to_dict = self.ref_lb.to_dict()
@@ -337,9 +366,11 @@ class TestProviderDataModels(base.TestCase):
         ref_list_dict.pop('l7policies', None)
         ref_list_dict.pop('sni_container_data', None)
         ref_list_dict.pop('sni_container_refs', None)
+        ref_list_dict.pop('tls_versions', None)
         ref_pool_dict = deepcopy(self.ref_pool_dict)
         ref_pool_dict['healthmonitor'] = None
         ref_pool_dict.pop('members', None)
+        ref_pool_dict.pop('tls_versions', None)
         ref_l7policy_dict = deepcopy(self.ref_l7policy_dict)
         ref_l7policy_dict.pop('rules', None)
 
@@ -419,7 +450,8 @@ class TestProviderDataModels(base.TestCase):
             vip_network_id=self.vip_network_id,
             vip_port_id=self.vip_port_id,
             vip_subnet_id=self.vip_subnet_id,
-            vip_qos_policy_id=self.vip_qos_policy_id)
+            vip_qos_policy_id=self.vip_qos_policy_id,
+            availability_zone=self.availability_zone)
 
         ref_lb_dict_with_listener = deepcopy(self.ref_lb_dict_with_listener)
         ref_lb_dict_with_listener['pools'] = None
